# Generated by Django 2.1.14 on 2019-12-04 10:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0031_merge_20191202_1119'),
        ('djautotask', '0032_auto_20191129_1501'),
    ]

    operations = [
    ]



# Generated by Django 2.1.14 on 2019-11-25 09:39

from django.db import migrations


class Migration(migrations.Migration):
    atomic = False
    dependencies = [
        ('djautotask', '0024_auto_20191122_1516'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='TicketPriority',
            new_name='Priority',
        ),
    ]



# Generated by Django 2.1.11 on 2019-09-20 12:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0004_auto_20190913_1425'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ticketstatus',
            name='value',
        ),
    ]
